/**************************************************************************
*************                                                 *************
*******                        SUCOMA32.HX                       **********
*************                                                 *************
***************************************************************************
*                                                                         *
*                            Copyright (c) by                             *
*                          Kloeckner-Moeller GmbH                         *
*                                                                         *
*                                                                         *
*                  SUCOMA 32 Bit DLL for Windows 95/NT 4.0                *
*                                                                         *
*                                                                         *
*                                                                         *
***************************************************************************/

#ifndef sucoma32_hx
#define sucoma32_hx


#ifdef __cplusplus              
    extern "C"  {
#endif                     
   

/* Errormessages */
#define    SUCOM_OK                        (0)    /* Function works correctly */
#define    SUCOM_COMM_ERROR                (1)    /* Reception error like Parity, Overrun ... */
#define    SUCOM_COM_PORT_NOT_FOUND        (2)    /* The interface does not exist or is faulty */
#define    SUCOM_ERROR_OPEN_COM_PORT       (3)    /* Internal PC interface error */
#define    SUCOM_COM_PORT_ALREADY_OPEN     (4)    /* The interface port is used by another application */
#define    SUCOM_PARAMETER_ERROR           (5)    /* At least one parameter is not valid */
#define    SUCOM_ERROR_ON_WRITING          (6)    /* A general write error has occured */
#define    SUCOM_ERROR_ON_READING          (7)    /* A general read error has occured */
#define    SUCOM_WRONG_ANSWER              (8)    /* Error reading PLC (not a KM PLC device ?!) */
#define    SUCOM_READING_TIMEOUT           (9)    /* TimeOut has occured reading the PLC */
#define    SUCOM_WRITING_TIMEOUT           (10)   /* TimeOut has occured writing the PLC */
#define    SUCOM_ERROR_INIT_TIMEOUT_VALUES (11)   /* Internal initialisation error of the interface */
#define    SUCOM_TOO_MUCH_MARKER           (12)   /* The requested marker data is outside the PLC marker range */


/* Klckner-Moeller PLC-typs */
#define KM_PLC_PS3                        (5)        /* PS3 */
#define KM_PLC_PS306                      (3)        /* PS306 */
#define KM_PLC_PS316                      (3)        /* PS316 */
#define KM_PLC_PS4_101                    (5)        /* PS4-101 */
#define KM_PLC_PS4_111                    (5)        /* PS4-111 */
#define KM_PLC_PS4_141                    (7)        /* PS4-141-MM1 */
#define KM_PLC_PS4_151                    (7)        /* PS4-151-MM1 */
#define KM_PLC_PS4_201                    (7)        /* PS4-201-MM1 */
#define KM_PLC_PS4_341                    (7)        /* PS4-341-MM1 */
#define KM_PLC_PS416                      (3)        /* PS416-CPU-200/300/400 */


/* Binary IEC-Datatyps */
#define    KM_BIT_NAME                     "BOOL"    /* !!! ONLY FOR READING !!! */
#define    KM_BYTE_NAME                    "BYTE"
#define    KM_WORD_NAME                    "WORD"
#define    KM_LONG_NAME                    "LONG"

/* Integer IEC-Datatyps */
#define    KM_VB_BOOL_NAME                 "VBBOOL"    /* !!! ONLY FOR READING !!! */
#define    KM_VB_BYTE_NAME                 "VBBYTE"
#define    KM_VB_WORD_NAME                 "VBWORD"
#define    KM_VB_LONG_NAME                 "VBLONG"

#define    KM_VB_SINT_NAME                 "VBSINT"
#define    KM_VB_USINT_NAME                "VBUSINT"
#define    KM_VB_INT_NAME                  "VBINT"
#define    KM_VB_UINT_NAME                 "VBUINT"
#define    KM_VB_DINT_NAME                 "VBDINT"
#define    KM_VB_UDINT_NAME                "VBUDINT"



/****** Functions for the SUCOMA32.DLL for 32-Bit-Applications ******/
/****** useable for MS-WINDOWS 95/NT 4.0                       ******/

#define KM_DLL_FCT_DEF    __declspec(dllexport) __stdcall 


/* Read DLL-Version/Sring */
unsigned short KM_DLL_FCT_DEF getSucomVersion   (   char*            xpVersionBuffer );


/* Write Data from PC -> PLC-Ram */
unsigned short KM_DLL_FCT_DEF writeDataToPLC    (   char*            xpComDevice,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    void*            xpDataToSend );

unsigned short KM_DLL_FCT_DEF writeDataToPLCex    ( char*            xpComDevice, 
                                                    int              xwPortID,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    unsigned short   xwNoOfElements,
                                                    void*            xpDataToSend );



/* Read Data from PLC-Ram -> PC */
unsigned short KM_DLL_FCT_DEF readDataFromPLC    (  char*            xpComDevice, 
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    void*            xpReadData );

unsigned short KM_DLL_FCT_DEF readDataFromPLCex    (char*            xpComDevice, 
                                                    int              xwPortID,
                                                    char*            xpDataType,
                                                    unsigned short   xwStartAddress,
                                                    unsigned short   xwNoOfElements,
                                                    void*            xpReadData );



unsigned short KM_DLL_FCT_DEF openComDevice     (   char*            xpComDevice,
                                                    int*             xwPortID );
                                                                
unsigned short KM_DLL_FCT_DEF closeComDevice    (   int              xwPortID );

unsigned short KM_DLL_FCT_DEF setPLCType        (   unsigned short   xwPLCType );



/****** Compatibility-Functions of the SUCOMA32.DLL for former 16-Bit-Apps ******/

int KM_DLL_FCT_DEF             GetDLLVersion    (   char*      xpVersion );


char KM_DLL_FCT_DEF            SendCPUData      (   char*      xpComDevice,
                                                    int        xhComHandle,
                                                    int        xbInitCom,    
                                                    int        xwPLCType,
                                                    int        xwOperandType,
                                                    int        xwStartAddress,
                                                    int        xwNoOfWords,
                                                    void*      xpDataToSend );

char KM_DLL_FCT_DEF            ReadCPUData      (   char*      xpComDevice,
                                                    int        xhComHandle,
                                                    int        xbInitCom,    
                                                    int        xwPLCType,
                                                    int        xwOperandType,
                                                    int        xwStartAddress,
                                                    int        xwNoOfWords,
                                                    void*      xpReadData );

   
#ifdef __cplusplus                
    }
#endif


#endif  


/******************************** EOF: SUCOMA32.hx ******************************************/
